classdef PersistentIp < handle
  % PersistentIp
  %   A persistent ip data structure
  %
  % Methods:
  %   getIp - Get the IP address
  %   setIp - Set the IP address
  %   getNetmask - Get the netmask
  %   setNetmask - Set the netmask
  %   getGateway - Get the gateway
  %   setGateway - Set the gateway
  %   getEnabled - Get if persistent ip is enabled
  %   setEnabled - Set if persistent ip is enabled
  %

  properties(Access=protected)
    mPtr = uint64(0);
  end

  methods(Access=public)
    function obj = PersistentIp(varargin)
      % PersistentIp
      %   Construct new persistent_ip class
      %
      % ----------
      %
      %   Create persistent ip
      %
      % Inputs:
      %   1 - string - IP address
      %   2 - string - Netmask
      %   3 - string - Gateway
      %   4 - logical - Enable or disable persistent ip
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        obj.mPtr = varargin{1};
      elseif nargin == 4 && (isStringScalar(varargin{1}) || ischar(varargin{1})) && (isStringScalar(varargin{2}) || ischar(varargin{2})) && (isStringScalar(varargin{3}) || ischar(varargin{3})) && isa(varargin{4}, 'logical')
        obj.mPtr = tof.mex('tof_persistent_ip_new', varargin{1}, varargin{2}, varargin{3}, varargin{4});
      else
        error("Can't construct empty object");
      end
    end

    function delete(obj)
      if obj.mPtr ~= 0
        tof.mex('tof_persistent_ip_delete', obj.mPtr);
        obj.mPtr = 0;
      end
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function ret_val = getIp(obj)
      % getIp
      %   Get the IP address
      %
      % Output:
      %   ret_val - string - the IP address
      %

      ret_val = tof.mex('tof_persistent_ip_get_ip', obj.mPtr);
    end

    function setIp(obj, ip)
      % setIp
      %   Set the IP address
      %
      % Inputs:
      %   ip - string - the IP address
      %

      tof.mex('tof_persistent_ip_set_ip', obj.mPtr, ip);
    end

    function ret_val = getNetmask(obj)
      % getNetmask
      %   Get the netmask
      %
      % Output:
      %   ret_val - string - The netmask
      %

      ret_val = tof.mex('tof_persistent_ip_get_netmask', obj.mPtr);
    end

    function setNetmask(obj, netmask)
      % setNetmask
      %   Set the netmask
      %
      % Inputs:
      %   netmask - string - The netmask
      %

      tof.mex('tof_persistent_ip_set_netmask', obj.mPtr, netmask);
    end

    function ret_val = getGateway(obj)
      % getGateway
      %   Get the gateway
      %
      % Output:
      %   ret_val - string - The gateway
      %

      ret_val = tof.mex('tof_persistent_ip_get_gateway', obj.mPtr);
    end

    function setGateway(obj, gateway)
      % setGateway
      %   Set the gateway
      %
      % Inputs:
      %   gateway - string - The gateway
      %

      tof.mex('tof_persistent_ip_set_gateway', obj.mPtr, gateway);
    end

    function ret_val = getEnabled(obj)
      % getEnabled
      %   Get if persistent ip is enabled
      %
      % Output:
      %   ret_val - logical - Is enabled
      %

      ret_val = tof.mex('tof_persistent_ip_get_enabled', obj.mPtr);
    end

    function setEnabled(obj, enabled)
      % setEnabled
      %   Set if persistent ip is enabled
      %
      % Inputs:
      %   enabled - logical - Is enabled
      %

      tof.mex('tof_persistent_ip_set_enabled', obj.mPtr, enabled);
    end

  end
end
