classdef Stream < handle
  % Stream
  %   This class describes the different data streams coming from the camera
  %
  % Methods:
  %   frameType - Get the frame type
  %   frameId - Get the frame id
  %   modulationFrequency - Get the modulation frequency of the frame
  %   integrationTime - Get the integration time of the frame
  %   process - Get a bit array of the processing performed on the frame
  %

  properties(Access=protected)
    mPtr = uint64(0);
  end

  methods(Access=public)
    function obj = Stream(varargin)
      % Stream
      %   Construct new stream class
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        obj.mPtr = varargin{1};
      else
        error("Can't construct empty object");
      end
    end

    function delete(obj)
      if obj.mPtr ~= 0
        tof.mex('tof_stream_delete', obj.mPtr);
        obj.mPtr = 0;
      end
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function ret_val = frameType(obj)
      % frameType
      %   Get the frame type
      %
      % Output:
      %   ret_val - FrameType - The frame type
      %

      ret_val = tof.mex('tof_stream_frame_type', obj.mPtr);
    end

    function ret_val = frameId(obj)
      % frameId
      %   Get the frame id
      %
      % Output:
      %   ret_val - numeric - The frame id
      %

      ret_val = tof.mex('tof_stream_frame_id', obj.mPtr);
      ret_val = double(ret_val);
    end

    function ret_val = modulationFrequency(obj)
      % modulationFrequency
      %   Get the modulation frequency of the frame
      %
      % Output:
      %   ret_val - numeric - The modulation frequency
      %

      ret_val = tof.mex('tof_stream_modulation_frequency', obj.mPtr);
      ret_val = double(ret_val);
    end

    function ret_val = integrationTime(obj)
      % integrationTime
      %   Get the integration time of the frame
      %
      % Output:
      %   ret_val - numeric - The integration time
      %

      ret_val = tof.mex('tof_stream_integration_time', obj.mPtr);
      ret_val = double(ret_val);
    end

    function ret_val = process(obj)
      % process
      %   Get a bit array of the processing performed on the frame
      %
      % Output:
      %   ret_val - numeric - A bit array
      %

      ret_val = tof.mex('tof_stream_process', obj.mPtr);
      ret_val = double(ret_val);
    end

  end
end
